function [value,I] = detDFmin(coordinates,elements)
%*** Compute min_{x\in T} |det(DF)| / (2*|T|) for all triangles
%     
value = Inf(size(elements,1),7);
C = [0,1;-1,0];
succ = [2,3,1];
for j=1:size(elements,1)
  coord = coordinates(elements(j,:),:);
  A = coord([1,4,2,5],:)-coord([2,1,4,6],:);
  B = coord([1,6,5,3],:)-coord([3,1,4,6],:);
  %*** Compte min(DF) for each vertex value(:,1:3) and edge value(:,4:6) 
  for k=1:3
    U = (A(1,:)  +4*A(1+succ(k),:)) * C * (B(1,:)  +4*B(1+succ(k),:))';
    V = (A(1+k,:)-  A(1+succ(k),:)) * C * (B(1,:)  +4*B(1+succ(k),:))' ...
      + (A(1,:)  +4*A(1+succ(k),:)) * C * (B(1+k,:)-  B(1+succ(k),:))';
    W(k) = (A(1+k,:)-  A(1+succ(k),:)) * C * (B(1+k,:)-  B(1+succ(k),:))';
    value(j,k) = U;
    if W(k) > 0 && abs(V+4*W(k)) < abs(4*W(k))
      value(j,k+3) = (U*W(k)-0.25*V^2)/W(k);
    end
  end
  %*** compute min(DF) in interior if Laplace(DF) is positive    
  if W(1) > 0 
    W(4) = (A(3,:)-A(2,:)) * C * (B(4,:)-B(2,:))' ...
         + (A(4,:)-A(2,:)) * C * (B(3,:)-B(2,:))';
    det = (4*W(1)*W(3)-W(4)^2);
    if det > 0
      b = [(A(3,:)-A(2,:)) * C * (B(1,:)+B(2,:))' ...
          +(A(1,:)+A(2,:)) * C * (B(3,:)-B(2,:))';...
           (A(4,:)-A(2,:)) * C * (B(1,:)+B(2,:))' ...
          +(A(1,:)+A(2,:)) * C * (B(4,:)-B(2,:))'];
      X = -1/det*[2*W(3),-W(4);-W(4),2*W(1)]*b;
      if X(1) > 0 && X(2) > 0 && X(1)+X(2) < 1     
        value(j,7) = (A(1,:)+A(2,:))*C*(B(1,:)+B(2,:))' + 1/2*X'*b;
      end
    end
  end
end
[value,I]=min(value,[],2);
%*** Compute area
[bary,wg] = quad2d(6);
phi  = [bary.*(2*bary-1),4*bary.*bary(:,[2,3,1])];
D = [-1,1,0;-1,0,1];
C = reshape(coordinates(elements',:),6,[]);
area = zeros(size(elements,1),1);
for k = 1:size(wg,1)
  dphi = [D.*(4*bary([k,k],:)-1), ...
          4*(D.*bary([k,k],[2,3,1])+D(:,[2,3,1]).*bary([k,k],:))];
  DF = reshape((dphi*C)',[],4);
  area =  area + wg(k)/2 * (DF(:,1).*DF(:,4)-DF(:,2).*DF(:,3));
end
value = value./(2*area);


